@@ -52,6 +52,7 @@
            #:extension
            #:sqltype
            #:table
+           #:matview
            #:column
            #:index
            #:fkey
@@ -66,7 +67,7 @@
            #:make-schema
            #:make-table
            #:create-table
-           #:make-view
+           #:make-matview
            #:make-sqltype
            #:make-column
            #:make-index
@@ -102,6 +103,11 @@
            #:table-trigger-list
            #:table-citus-rule
 
+           #:matview-name
+           #:matview-source-name
+           #:matview-schema
+           #:matview-definition
+
            #:extension-name
            #:extension-schema
 
@@ -560,6 +566,17 @@
            #:instanciate-table-copy-object
            #:concurrency-support
 
+           #:filter-list-to-where-clause
+           #:fetch-columns
+           #:fetch-indexes
+           #:fetch-foreign-keys
+           #:fetch-comments
+           #:get-column-sql-expression
+           #:get-column-list
+           #:format-matview-name
+           #:create-matviews
+           #:drop-matviews
+
            ;; database cast machinery
            #:*default-cast-rules*
            #:*cast-rules*
@@ -704,6 +721,7 @@
 		#:create-tables
                 #:format-vector-row)
   (:export #:dbf-connection
+           #:*db3-default-cast-rules*
            #:copy-db3
 	   #:map-rows
 	   #:copy-to
@@ -850,7 +868,8 @@
                 #:*sqlite-default-cast-rules*)
   (:import-from #:pgloader.source.db3
                 #:copy-db3
-                #:dbf-connection)
+                #:dbf-connection
+                #:*db3-default-cast-rules*)
   (:import-from #:pgloader.source.ixf
                 #:copy-ixf
                 #:ixf-connection)
