@@ -28,6 +28,7 @@
 		((:column rule-source-column) nil c-s-p)
 		((:typemod typemod-expr) nil tm-s-p)
 		((:default rule-source-default) nil d-s-p)
+                ((:signed rule-signed) nil s-s-p)
                 ((:unsigned rule-unsigned) nil u-s-p)
 		((:not-null rule-source-not-null) nil n-s-p)
 		((:auto-increment rule-source-auto-increment))
@@ -57,10 +58,11 @@
 
              ;; otherwide, we do the full dance
              (and
-              (or (and t-s-p (string= type rule-source-type)))
+              (or (and t-s-p (string-equal type rule-source-type)))
               (or (null tm-s-p) (when typemod
                                   (typemod-expr-matches-p typemod-expr typemod)))
-              (or (null d-s-p)  (string= default rule-source-default))
+              (or (null d-s-p)  (string-equal default rule-source-default))
+              (or (null s-s-p)  (eq unsigned (not rule-signed)))
               (or (null u-s-p)  (eq unsigned rule-unsigned))
               (or (null n-s-p)  (eq not-null rule-source-not-null))
 
