@@ -36,14 +36,24 @@
 	     :target (:type "boolean" :drop-typemod t)
 	     :using pgloader.transforms::tinyint-to-boolean)
 
+    ;; bit(1) is most often used as a boolean too
     (:source (:type "bit" :typemod (= 1 precision))
 	     :target (:type "boolean" :drop-typemod t)
 	     :using pgloader.transforms::bits-to-boolean)
 
-    ;; bigint(20) unsigned (or not, actually) does not fit into PostgreSQL
-    ;; bigint (-9223372036854775808 to +9223372036854775807):
+    ;; bit(X) might be flags or another use case for bitstrings
+    (:source (:type "bit")
+	     :target (:type "bit" :drop-typemod nil)
+	     :using pgloader.transforms::bits-to-hex-bitstring)
+
+    ;; bigint(20) signed do fit into PostgreSQL bigint
+    ;; (-9223372036854775808 to +9223372036854775807):
+    (:source (:type "bigint" :signed t)
+             :target (:type "bigint" :drop-typemod t))
+
+    ;; bigint(20) unsigned does not fit into PostgreSQL bigint
     (:source (:type "bigint" :typemod (< 19 precision))
-     :target (:type "numeric" :drop-typemod t))
+             :target (:type "numeric" :drop-typemod t))
 
     ;; now unsigned types
     (:source (:type "tinyint" :unsigned t)
