@@ -4,31 +4,6 @@
 
 (in-package :pgloader.source.mysql)
 
-(defclass copy-mysql (db-copy)
-  ((encoding :accessor encoding         ; allows forcing encoding
-             :initarg :encoding
-             :initform nil)
-   (range-list :accessor range-list
-               :initarg :range-list
-               :initform nil))
-  (:documentation "pgloader MySQL Data Source"))
-
-(defmethod initialize-instance :after ((source copy-mysql) &key)
-  "Add a default value for transforms in case it's not been provided."
-  (let ((transforms (and (slot-boundp source 'transforms)
-                         (slot-value  source 'transforms))))
-    (when (and (slot-boundp source 'fields) (slot-value source 'fields))
-      ;; cast typically happens in copy-database in the schema structure,
-      ;; and the result is then copied into the copy-mysql instance.
-      (unless (and (slot-boundp source 'columns) (slot-value source 'columns))
-        (setf (slot-value source 'columns)
-              (mapcar #'cast (slot-value source 'fields))))
-
-      (unless transforms
-        (setf (slot-value source 'transforms)
-              (mapcar #'column-transform (slot-value source 'columns)))))))
-
-
 ;;;
 ;;; Implement the specific methods
 ;;;
@@ -166,7 +141,6 @@ Illegal ~a character starting at position ~a~@[: ~a~].~%"
                            (catalog catalog)
                            &key
                              materialize-views
-                             only-tables
                              (create-indexes   t)
                              (foreign-keys     t)
                              including
@@ -174,50 +148,55 @@ Illegal ~a character starting at position ~a~@[: ~a~].~%"
   "MySQL introspection to prepare the migration."
   (let ((schema        (add-schema catalog (catalog-name catalog)
                                    :in-search-path t))
-        (view-names    (unless (eq :all materialize-views)
-                         (mapcar #'car materialize-views))))
+        (including     (filter-list-to-where-clause mysql including))
+        (excluding     (filter-list-to-where-clause mysql excluding :not t)))
     (with-stats-collection ("fetch meta data"
                             :use-result-as-rows t
                             :use-result-as-read t
                             :section :pre)
-        (with-connection (*connection* (source-db mysql))
-          ;; If asked to MATERIALIZE VIEWS, now is the time to create them in
-          ;; MySQL, when given definitions rather than existing view names.
-          (when (and materialize-views (not (eq :all materialize-views)))
-            (create-my-views materialize-views))
+      (with-connection (*connection* (source-db mysql))
+        ;; If asked to MATERIALIZE VIEWS, now is the time to create them in
+        ;; MySQL, when given definitions rather than existing view names.
+        (when (and materialize-views (not (eq :all materialize-views)))
+          (create-matviews materialize-views mysql))
 
-          ;; fetch table and columns metadata, covering table and column comments
-          (list-all-columns schema
-                            :only-tables only-tables
-                            :including including
-                            :excluding excluding)
+        ;; fetch table and columns metadata, covering table and column comments
+        (fetch-columns schema mysql
+                       :including including
+                       :excluding excluding)
 
-          ;; fetch view (and their columns) metadata, covering comments too
-          (cond (view-names (list-all-columns schema
-                                              :only-tables view-names
-                                              :table-type :view))
+        ;; fetch view (and their columns) metadata, covering comments too
+        (let* ((view-names (unless (eq :all materialize-views)
+                             (mapcar #'matview-source-name materialize-views)))
+               (including
+                (loop :for (schema-name . view-name) :in view-names
+                   :collect (make-string-match-rule :target view-name)))
+               (including-clause (filter-list-to-where-clause mysql including)))
+          (cond (view-names
+                 (fetch-columns schema mysql
+                                :including including-clause
+                                :excluding excluding
+                                :table-type :view))
 
                 ((eq :all materialize-views)
-                 (list-all-columns schema :table-type :view)))
+                 (fetch-columns schema mysql :table-type :view))))
 
-          (when foreign-keys
-            (list-all-fkeys schema
-                            :only-tables only-tables
-                            :including including
-                            :excluding excluding))
-
-          (when create-indexes
-            (list-all-indexes schema
-                              :only-tables only-tables
+        (when foreign-keys
+          (fetch-foreign-keys schema mysql
                               :including including
                               :excluding excluding))
 
-          ;; return how many objects we're going to deal with in total
-          ;; for stats collection
-          (+ (count-tables catalog)
-             (count-views catalog)
-             (count-indexes catalog)
-             (count-fkeys catalog))))
+        (when create-indexes
+          (fetch-indexes schema mysql
+                         :including including
+                         :excluding excluding))
+
+        ;; return how many objects we're going to deal with in total
+        ;; for stats collection
+        (+ (count-tables catalog)
+           (count-views catalog)
+           (count-indexes catalog)
+           (count-fkeys catalog))))
 
     catalog))
 
@@ -227,7 +206,7 @@ Illegal ~a character starting at position ~a~@[: ~a~].~%"
    migration purpose."
   (when materialize-views
     (with-connection (*connection* (source-db mysql))
-      (drop-my-views materialize-views))))
+      (drop-matviews materialize-views mysql))))
 
 (defvar *decoding-as* nil
   "Special per-table encoding/decoding overloading rules for MySQL.")
