@@ -3,66 +3,44 @@
 ;;;
 (in-package :pgloader.source.sqlite)
 
-(defvar *sqlite-db* nil
-  "The SQLite database connection handler.")
+(defclass copy-sqlite (db-copy)
+  ((db :accessor db :initarg :db))
+  (:documentation "pgloader SQLite Data Source"))
 
-;;;
-;;; Integration with the pgloader Source API
-;;;
-(defclass sqlite-connection (fd-connection)
-  ((has-sequences :initform nil :accessor has-sequences)))
-
-(defmethod initialize-instance :after ((slconn sqlite-connection) &key)
-  "Assign the type slot to sqlite."
-  (setf (slot-value slconn 'type) "sqlite"))
-
-(defmethod open-connection ((slconn sqlite-connection) &key check-has-sequences)
-  (setf (conn-handle slconn)
-        (sqlite:connect (fd-path slconn)))
-  (log-message :debug "CONNECTED TO ~a" (fd-path slconn))
-  (when check-has-sequences
-    (let ((sql (format nil (sql "/sqlite/sqlite-sequence.sql"))))
-      (log-message :sql "SQLite: ~a" sql)
-      (when (sqlite:execute-single (conn-handle slconn) sql)
-        (setf (has-sequences slconn) t))))
-  slconn)
-
-(defmethod close-connection ((slconn sqlite-connection))
-  (sqlite:disconnect (conn-handle slconn))
-  (setf (conn-handle slconn) nil)
-  slconn)
-
-(defmethod clone-connection ((slconn sqlite-connection))
-  (change-class (call-next-method slconn) 'sqlite-connection))
-
-(defmethod query ((slconn sqlite-connection) sql &key)
-  (log-message :sql "SQLite: sending query: ~a" sql)
-  (sqlite:execute-to-list (conn-handle slconn) sql))
-
-
 ;;;
 ;;; SQLite schema introspection facilities
 ;;;
-(defun filter-list-to-where-clause (filter-list
-                                    &optional
-                                      not
-                                      (table-col  "tbl_name"))
+(defun sqlite-encoding (db)
+  "Return a BABEL suitable encoding for the SQLite db handle."
+  (let ((encoding-string (sqlite:execute-single db "pragma encoding;")))
+    (cond ((string-equal encoding-string "UTF-8")    :utf-8)
+          ((string-equal encoding-string "UTF-16")   :utf-16)
+          ((string-equal encoding-string "UTF-16le") :utf-16le)
+          ((string-equal encoding-string "UTF-16be") :utf-16be))))
+
+(defmethod filter-list-to-where-clause ((sqlite copy-sqlite)
+                                        filter-list
+                                        &key
+                                          not
+                                          (table-col  "tbl_name")
+                                          &allow-other-keys)
   "Given an INCLUDING or EXCLUDING clause, turn it into a SQLite WHERE clause."
   (mapcar (lambda (table-name)
             (format nil "(~a ~:[~;NOT ~]LIKE '~a')"
                     table-col not table-name))
           filter-list))
 
-(defun list-tables (&key
+(defun list-tables (sqlite
+                    &key
                       (db *sqlite-db*)
                       including
                       excluding)
   "Return the list of tables found in SQLITE-DB."
-  (let ((sql (format nil (sql "/sqlite/list-tables.sql")
-                     including          ; do we print the clause?
-                     (filter-list-to-where-clause including nil)
-                     excluding          ; do we print the clause?
-                     (filter-list-to-where-clause excluding t))))
+  (let ((sql (sql "/sqlite/list-tables.sql"
+                  including             ; do we print the clause?
+                  (filter-list-to-where-clause sqlite including :not nil)
+                  excluding             ; do we print the clause?
+                  (filter-list-to-where-clause sqlite excluding :not t))))
     (log-message :sql "~a" sql)
     (loop for (name) in (sqlite:execute-to-list db sql)
        collect name)))
@@ -70,7 +48,7 @@
 (defun find-sequence (db table-name column-name)
   "Find if table-name.column-name is attached to a sequence in
    sqlite_sequence catalog."
-  (let* ((sql (format nil (sql "/sqlite/find-sequence.sql") table-name))
+  (let* ((sql (sql "/sqlite/find-sequence.sql" table-name))
          (seq (sqlite:execute-single db sql)))
     (when (and seq (not (zerop seq)))
       ;; magic marker for `apply-casting-rules'
@@ -83,7 +61,7 @@
    added to the table. So we might fail to FIND-SEQUENCE, and still need to
    consider the column has an autoincrement. Parse the SQL definition of the
    table to find out."
-  (let* ((sql (format nil (sql "/sqlite/get-create-table.sql") table-name))
+  (let* ((sql (sql "/sqlite/get-create-table.sql" table-name))
          (create-table (sqlite:execute-single db sql))
          (open-paren   (+ 1 (position #\( create-table)))
          (close-paren  (position #\) create-table :from-end t))
@@ -111,7 +89,7 @@
 (defun list-columns (table &key db-has-sequences (db *sqlite-db*) )
   "Return the list of columns found in TABLE-NAME."
   (let* ((table-name (table-source-name table))
-         (sql        (format nil (sql "/sqlite/list-columns.sql") table-name)))
+         (sql        (sql "/sqlite/list-columns.sql" table-name)))
     (loop :for (ctid name type nullable default pk-id)
        :in (sqlite:execute-to-list db sql)
        :do (let* ((ctype (normalize type))
@@ -136,14 +114,18 @@
                (setf (coldef-extra field) :auto-increment))
              (add-field table field)))))
 
-(defun list-all-columns (schema
-                         &key
-                           db-has-sequences
-                           (db *sqlite-db*)
-                           including
-                           excluding)
+(defmethod fetch-columns ((schema schema)
+                          (sqlite copy-sqlite)
+                          &key
+                            db-has-sequences
+                            table-type
+                            including
+                            excluding
+                          &aux (db (conn-handle (source-db sqlite))))
   "Get the list of SQLite column definitions per table."
-  (loop :for table-name :in (list-tables :db db
+  (declare (ignore table-type))
+  (loop :for table-name :in (list-tables sqlite
+                                         :db db
                                          :including including
                                          :excluding excluding)
      :do (let ((table (add-table schema table-name)))
@@ -186,15 +168,14 @@
 
 (defun list-index-cols (index-name &optional (db *sqlite-db*))
   "Return the list of columns in INDEX-NAME."
-  (let ((sql (format nil (sql "/sqlite/list-index-cols.sql") index-name)))
+  (let ((sql (sql "/sqlite/list-index-cols.sql" index-name)))
     (loop :for (index-pos table-pos col-name) :in (sqlite:execute-to-list db sql)
        :collect (apply-identifier-case col-name))))
 
 (defun list-indexes (table &optional (db *sqlite-db*))
   "Return the list of indexes attached to TABLE."
   (let* ((table-name (table-source-name table))
-         (sql
-          (format nil (sql "/sqlite/list-table-indexes.sql") table-name)))
+         (sql (sql "/sqlite/list-table-indexes.sql" table-name)))
     (loop
        :for (seq index-name unique origin partial)
        :in (sqlite:execute-to-list db sql)
@@ -213,7 +194,9 @@
   ;; might create double primary key indexes here
   (add-unlisted-primary-key-index table))
 
-(defun list-all-indexes (schema &key (db *sqlite-db*))
+(defmethod fetch-indexes ((schema schema) (sqlite copy-sqlite)
+                          &key &allow-other-keys
+                          &aux (db (conn-handle (source-db sqlite))))
   "Get the list of SQLite index definitions per table."
   (loop :for table :in (schema-table-list schema)
      :do (list-indexes table db)))
@@ -225,8 +208,7 @@
 (defun list-fkeys (table &optional (db *sqlite-db*))
   "Return the list of indexes attached to TABLE."
   (let* ((table-name (table-source-name table))
-         (sql
-          (format nil (sql "/sqlite/list-fkeys.sql") table-name)))
+         (sql (sql "/sqlite/list-fkeys.sql" table-name)))
     (loop
        :with fkey-table := (make-hash-table)
        :for (id seq ftable-name from to on-update on-delete match)
@@ -262,7 +244,9 @@
                               (when ftable (format-table-name ftable))
                               to))))))
 
-(defun list-all-fkeys (schema &key (db *sqlite-db*))
+(defmethod fetch-foreign-keys ((schema schema) (sqlite copy-sqlite)
+                               &key &allow-other-keys
+                               &aux (db (conn-handle (source-db sqlite))))
   "Get the list of SQLite foreign keys definitions per table."
   (loop :for table :in (schema-table-list schema)
      :do (list-fkeys table db)))
